(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     95785,       2382]
NotebookOptionsPosition[     91560,       2249]
NotebookOutlinePosition[     91915,       2265]
CellTagsIndexPosition[     91872,       2262]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["MatchEstimation Template Example", "Title"],

Cell["David Santiago", "Subtitle"],

Cell[CellGroupData[{

Cell["Import the Packages You Need", "Section"],

Cell["Some useful packages are already loaded below. ", "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Combinatorica`\>\"", "]"}]], "Input",
 CellChangeTimes->{3.389813189162752*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Histograms`\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{3.389813212546376*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"ToFileName", "[", 
    RowBox[{"Extract", "[", 
     RowBox[{
      RowBox[{"\"\<FileName\>\"", "/.", 
       RowBox[{"NotebookInformation", "[", 
        RowBox[{"EvaluationNotebook", "[", "]"}], "]"}]}], ",", 
      RowBox[{"{", "1", "}"}], ",", "FrontEnd`FileName"}], "]"}], "]"}], 
   "]"}], ";"}]], "Input"],

Cell["\<\
The MatchEstimation toolkit includes all of the packages it uses itself. The \
packages included above are for use in this notebook. The line below includes \
the MatchEstimation toolkit. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MatchEstimation`\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load Data", "Section"],

Cell["\<\
Load any data you need and create any other variables you will need later. \
Alternatively, if you are doing Monte Carlo simulations, generate the data \
you need below. The code below generates data randomly instead of loading it \
from a file, and calculates the matches based on the payoff function. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"numNests", " ", "=", " ", "10"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"numMatches", "=", "50"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x1m", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"4", "*", 
       RowBox[{"Random", "[", 
        RowBox[{"ChiDistribution", "[", "1.5", "]"}], "]"}]}], " ", "+", " ", 
      "9"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"h", ",", " ", "1", ",", "numNests"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "numMatches"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x1f", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"4", "*", 
       RowBox[{"Random", "[", 
        RowBox[{"ChiDistribution", "[", "2", "]"}], "]"}]}], "+", "9"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", "numNests"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "1", ",", "numMatches"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x2m", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Random", "[", 
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"10", ",", " ", "1"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", "numNests"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "numMatches"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x2f", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Random", "[", 
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"10", ",", "1"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", "numNests"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "numMatches"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x3m", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Random", "[", 
      RowBox[{"LogNormalDistribution", "[", 
       RowBox[{"1", ",", " ", ".5"}], "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", "numNests"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "numMatches"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"x3f", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Random", "[", 
       RowBox[{"LogNormalDistribution", "[", 
        RowBox[{"1", ",", " ", "1.5"}], "]"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"h", ",", "1", ",", "numNests"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "numMatches"}], "}"}]}], "]"}]}], ";"}], 
  " "}]], "Input"],

Cell[TextData[{
 "The match payoff function used to generate the data below is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["x1m", "ni"], "*", 
     SubscriptBox["x1f", "nj"]}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", "1"], " ", 
     SubscriptBox["x2m", "ni"], "*", 
     SubscriptBox["x2f", "nj"]}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", "2"], " ", 
     SubscriptBox["x3m", "ni"], "*", 
     SubscriptBox["x3f", "nj"]}]}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " indexes a nest/market, ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " indexes the upstream agent, and ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]]],
 " indexes the downstream agent. The parameters to be estimated are ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "2"], TraditionalForm]]],
 ". The six data variables represent 3 different characteristics of the \"m\" \
and \"f\" sides of the market (ie, x1m is the first characteristic of the \"m\
\" market participants and x3f is the third characteristic of the \"f\" \
market participants). \n\nThe following line generates a matrix of the \
payoffs for every possible pairing. These payoffs have a random component. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"matchPayoff", "[", 
   RowBox[{"n_", ",", "i_", ",", "j_", ",", "b1_", ",", "b2_"}], "]"}], ":=", 
  
  RowBox[{
   RowBox[{
    RowBox[{"x1m", "[", 
     RowBox[{"[", 
      RowBox[{"n", ",", "i"}], "]"}], "]"}], "*", 
    RowBox[{"x1f", "[", 
     RowBox[{"[", 
      RowBox[{"n", ",", "j"}], "]"}], "]"}]}], " ", "+", " ", 
   RowBox[{"b1", "*", 
    RowBox[{"x2m", "[", 
     RowBox[{"[", 
      RowBox[{"n", ",", "i"}], "]"}], "]"}], "*", 
    RowBox[{"x2f", "[", 
     RowBox[{"[", 
      RowBox[{"n", ",", "j"}], "]"}], "]"}]}], " ", "+", " ", 
   RowBox[{"b2", "*", 
    RowBox[{"x3m", "[", 
     RowBox[{"[", 
      RowBox[{"n", ",", "i"}], "]"}], "]"}], "*", 
    RowBox[{"x3f", "[", 
     RowBox[{"[", 
      RowBox[{"n", ",", "j"}], "]"}], "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"payoffMatrices", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"matchPayoff", "[", 
       RowBox[{"h", ",", " ", "i", ",", "j", ",", " ", "5", ",", " ", "3"}], 
       "]"}], " ", "+", " ", 
      RowBox[{"Random", "[", 
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}], "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"h", ",", " ", "1", ",", " ", "numNests"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", "numMatches"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "1", ",", " ", "numMatches"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
generateAssignmentMatrix is a routine in the MatchEstimation toolkit that \
takes a payoff matrix and returns a matrix of ones and zeros; a 1 signifies \
that the upstream agent and downstream agent corresponding to that row and \
column are matched. In the following line this is converted to a match matrix \
with another MatchEstimation toolkit routine, matchIndexMatrix, which lists \
the matched downstream partner for each upstream agent in each market.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"matchMatrices", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"generateAssignmentMatrix", "[", 
      RowBox[{
       RowBox[{"payoffMatrices", "[", 
        RowBox[{"[", "h", "]"}], "]"}], ",", " ", "1"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"h", ",", "1", ",", "numNests"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mate", " ", "=", " ", 
   RowBox[{"matchIndexMatrix", "[", 
    RowBox[{"matchMatrices", ",", " ", "1"}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perform Precalculations for the Objective Function ", "Section"],

Cell[TextData[{
 "The two lines below generate inequality lists with allPairsInequalityList \
and randomInequalityList, two MatchEstimation routines. An inequality list is \
a list of tuples of the form {{n,i1,p1},{n,i2,p2}}; each of the inner tuples \
indexes a market (n, note that both market indexes will always be the same), \
an upstream agent (i1, i2) in that market, and one of that agent's match \
partners (p1, p2), and so contains all of the information necessary to \
construct one of the inequalities in the objective function: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["f", "\[Beta]"], "(", 
       RowBox[{"n", ",", "i1", ",", 
        RowBox[{"\[Mu]", "(", 
         RowBox[{"i1", ",", "p1"}], ")"}]}], ")"}], "+", 
      RowBox[{
       SubscriptBox["f", "\[Beta]"], "(", 
       RowBox[{"n", ",", "i2", ",", 
        RowBox[{"\[Mu]", "(", 
         RowBox[{"i2", ",", "p2"}], ")"}]}], ")"}]}], ">", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", "\[Beta]"], "(", 
       RowBox[{"n", ",", "i1", ",", 
        RowBox[{"\[Mu]", "(", 
         RowBox[{"i2", ",", "p2"}], ")"}]}], ")"}], "+", 
      RowBox[{
       SubscriptBox["f", "\[Beta]"], "(", 
       RowBox[{"n", ",", "i2", ",", 
        RowBox[{"\[Mu]", "(", 
         RowBox[{"i1", ",", "p1"}], ")"}]}], ")"}]}]}], "]"}], 
   TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", "(", 
    RowBox[{"i1", ",", "p1"}], ")"}], TraditionalForm]]],
 " indicates (for example) the p1'st downstream partner of the i1'th upstream \
agent. The only difference between allPairsInequalityList and \
randomInequalityList is that the former returns all possible inequalities \
consistent with the maximum score objective function, while the latter \
returns a random subset. Since this example is still small and managable, rp \
is not used, but all the code below works by simply replacing ap with rp. For \
large problems, the list of all pairs will be too large for practical usage, \
in which case rp can be used to reduce the computational burden in  exchange \
for discarding some information when forming the estimate. "
}], "Text",
 CellChangeTimes->{{3.432874885656086*^9, 3.432874961013495*^9}, {
  3.432875158691217*^9, 3.4328751944623137`*^9}, {3.432875720626233*^9, 
  3.432875751548849*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ap", " ", "=", " ", 
   RowBox[{"allPairsInequalityList", "[", "mate", "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rp", "=", 
   RowBox[{"randomInequalityList", "[", 
    RowBox[{"mate", ",", " ", "100"}], "]"}]}], ";"}]], "Input"],

Cell["\<\
The function precomputeCovariates below takes the data loaded above and \
generates the data array and data map, which are discussed in the \
documentation. The function makes use of a list of all inequalities to create \
the data needed for each inequality and pack it into the array. It is \
generally easiest to generate the data map at the same time as the data \
array, as below, to reuse variables where possible and keep the code close \
together. Note also how this code generates two different data maps, one for \
nest subsampling and the other for coalition subsampling, so we can see how \
both work simply by passing one or the other row of the dataMap variable into \
functions that use them. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"precomputeCovariates", "[", "matchMtx_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nn", ",", "i1", ",", "i2", ",", "p1", ",", "p2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"nn", ":=", 
       RowBox[{"ap", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "1"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i1", ":=", 
       RowBox[{"ap", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"i2", ":=", 
       RowBox[{"ap", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p1", ":=", 
       RowBox[{"ap", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "1", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"p2", ":=", 
       RowBox[{"ap", "[", 
        RowBox[{"[", 
         RowBox[{"ineq", ",", "2", ",", "3"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateObsExpr", "[", 
        RowBox[{"varM_", ",", "varF_"}], "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "i1"}], "]"}], "]"}], "*", 
           RowBox[{"varF", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", " ", 
              RowBox[{"mate", "[", 
               RowBox[{"[", 
                RowBox[{"nn", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
               "]"}]}], " ", "]"}], "]"}]}], " ", "\[IndentingNewLine]", "+", 
          
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "i2"}], "]"}], "]"}], "*", 
           RowBox[{"varF", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", 
              RowBox[{"mate", "[", 
               RowBox[{"[", 
                RowBox[{"nn", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
               "]"}]}], " ", "]"}], "]"}]}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"covariateCFExpr", "[", 
        RowBox[{"varM_", ",", "varF_"}], "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "2", ",", "i1", ",", "p1"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"matchMtx", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "2", ",", "i2", ",", "p2"}], "]"}], "]"}], 
           "\[NotEqual]", "0"}]}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "i1"}], "]"}], "]"}], "*", 
           RowBox[{"varF", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", " ", 
              RowBox[{"mate", "[", 
               RowBox[{"[", 
                RowBox[{"nn", ",", "2", ",", "i2", ",", "p2"}], "]"}], 
               "]"}]}], " ", "]"}], "]"}]}], " ", "\[IndentingNewLine]", "+", 
          
          RowBox[{
           RowBox[{"varM", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", "i2"}], "]"}], "]"}], "*", 
           RowBox[{"varF", "[", 
            RowBox[{"[", 
             RowBox[{"nn", ",", 
              RowBox[{"mate", "[", 
               RowBox[{"[", 
                RowBox[{"nn", ",", "2", ",", "i1", ",", "p1"}], "]"}], 
               "]"}]}], " ", "]"}], "]"}]}]}], ",", "Null"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "Note", " ", "that", " ", "the", " ", "code", " ", "above", " ", 
         "will", " ", "insert", " ", "Nulls", " ", "in", " ", "the", " ", 
         "cases", " ", "where", " ", "the", " ", "match", " ", "matrix", " ", 
         "is", " ", "referring", " ", "to", " ", "nonexistent", " ", 
         RowBox[{"elements", ".", " ", "We"}], " ", "want", " ", "to", " ", 
         "delete", " ", 
         RowBox[{"those", ".", " ", "We"}], " ", "can", " ", "do", " ", "it", 
         " ", "this", " ", "way"}], ",", " ", 
        RowBox[{"that", " ", "is"}], ",", " ", 
        RowBox[{"independently", " ", "for", " ", "each", " ", "covariate"}], 
        ",", " ", 
        RowBox[{
         RowBox[{
         "because", " ", "the", " ", "condition", " ", "that", " ", "causes", 
          " ", "a", " ", "null", " ", "insertion", " ", "is", 
          "\[IndentingNewLine]", "independent", " ", "of", " ", "the", " ", 
          "variables", " ", "being", " ", 
          RowBox[{"considered", ".", " ", "The"}], " ", "DeleteCases", " ", 
          "statements", " ", "simply", " ", "pull", " ", "out", 
          "\[IndentingNewLine]", "only", " ", "the", " ", "non"}], "-", 
         RowBox[{"null", " ", 
          RowBox[{"elements", ".", " ", "As"}], " ", "we", " ", "said"}]}], 
        ",", " ", 
        RowBox[{
        "these", " ", "are", " ", "guaranteed", " ", "to", " ", "line", " ", 
         "up", " ", 
         RowBox[{"correctly", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"cov1", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"covariateObsExpr", "[", 
             RowBox[{"x1m", ",", "x1f"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "Null"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cov2", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"covariateObsExpr", "[", 
             RowBox[{"x2m", ",", "x2f"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "Null"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cov3", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"covariateObsExpr", "[", 
             RowBox[{"x3m", ",", "x3f"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "Null"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cf1", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"covariateCFExpr", "[", 
             RowBox[{"x1m", ",", "x1f"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "Null"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cf2", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"covariateCFExpr", "[", 
             RowBox[{"x2m", ",", "x2f"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "Null"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cf3", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"covariateCFExpr", "[", 
             RowBox[{"x3m", ",", "x3f"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"ineq", ",", " ", "1", ",", " ", 
              RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], ",", " ", 
          "Null"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dataArray", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"{", 
         RowBox[{
         "cov1", ",", "cov2", ",", "cov3", ",", "cf1", ",", "cf2", ",", 
          "cf3"}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"markets", "=", " ", 
       RowBox[{"Developer`ToPackedArray", " ", "[", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", "nn", "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"ineq", ",", "1", ",", 
            RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"groups", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", "\[IndentingNewLine]", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i1", ",", "i2"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"ineq", ",", " ", "1", ",", " ", 
            RowBox[{"Length", "[", "ap", "]"}]}], "}"}]}], "]"}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"dataMap", " ", "=", " ", 
       RowBox[{"Developer`ToPackedArray", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"markets", ",", " ", "groups"}], "}"}], "]"}], "]"}]}], 
      ";"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"precomputeCovariates", "[", "mate", "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Create an Objective Function", "Section"],

Cell[TextData[{
 "First, we assign helpful mnemonics to the indexes of the data array that we \
use. Then we create an objective function that calculates the score based on \
the data array and the parameters given as arguments. Note the highly \
vectorized nature of the code; the last two lines of code are a way to \
perform a vectorized \"If\" statement in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", which does not otherwise have one. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kCOV1", "=", "1"}], ";", " ", 
  RowBox[{"kCOV2", "=", "2"}], ";", 
  RowBox[{"kCOV3", "=", "3"}], ";", 
  RowBox[{"kCF1", "=", "4"}], ";", 
  RowBox[{"kCF2", "=", "5"}], ";", 
  RowBox[{"kCF3", "=", "6"}], ";", " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"objective", "[", 
    RowBox[{"dataArray_", ",", " ", "b1_", ",", "b2_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"values", ",", " ", "onesorzero"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"values", " ", "=", " ", 
       RowBox[{
        RowBox[{"dataArray", "[", 
         RowBox[{"[", "kCOV1", "]"}], "]"}], "+", 
        RowBox[{"b1", "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", "kCOV2", "]"}], "]"}]}], "+", 
        RowBox[{"b2", "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", "kCOV3", "]"}], "]"}]}], "-", 
        RowBox[{"dataArray", "[", 
         RowBox[{"[", "kCF1", "]"}], "]"}], "-", 
        RowBox[{"b1", "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", "kCF2", "]"}], "]"}]}], "-", 
        RowBox[{"b2", "*", 
         RowBox[{"dataArray", "[", 
          RowBox[{"[", "kCF3", "]"}], "]"}]}]}]}], ";", "\[IndentingNewLine]",
       
      RowBox[{"onesorzero", " ", "=", " ", 
       RowBox[{
        RowBox[{"values", " ", "/", " ", 
         RowBox[{"Abs", "[", "values", "]"}]}], "+", "1.0"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Total", "[", "onesorzero", "]"}], "/", "2."}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"],

Cell[TextData[{
 "As an example, the following line calculates the score at the true values \
of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Beta]", "1"], "=", "5"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Beta]", "2"], "=", "3"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"objective", "[", 
   RowBox[{"dataArray", ",", " ", "5", ",", " ", "3"}], "]"}], "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.009999999999999735`", ",", "12161.`"}], "}"}]], "Output",
 CellChangeTimes->{3.3898142014984193`*^9, 3.3898162632130194`*^9}]
}, Open  ]],

Cell["\<\
Finally, the objective function is graphed, holding the second argument \
constant at the true value. Since there is a random component to the payoffs, \
the peak will not necessarily be aligned with the true values. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"objective", "[", 
    RowBox[{"dataArray", ",", " ", "b1", ",", "3"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"b1", ",", "0", ",", "20"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN3Hk8VP/3B/AJKTslIiHJLtGmlKZCKm1CFIqEkGiRrZKdiGQnW2RNlCjJ
npEtIVsqRZFPkTVK+V6Pub95/f6q5+Oc9znn3rlzF2asMj+ve4aJQqGMslAo
8/8uC5pde062YwfxX4rHMRr1379vb78HkzakUQccO9ztxuimHKdRm/urV383
6KTHCT899qjO9jlpYxo1uS7R8T+xLnq+CY06Ef1E7mMQaVMaVcuqvq9lhm4P
wjEbP8XXWHbT46do1O/Mv/SLW0lb0Kg7Wjh5cqnv6PlnaNSwJIna5Ad0Uyxp
1C/2qjcihHvoccKq2w9uDfAjbUWj3uSwGHefoJtiTaN+6HLJcTB7z7ByRsgZ
iya6PQh7O6WJGqp9oMfP0qgdGs879meQtqNR5Za+Cd2x7CM9n/DVT1/3rvek
m3KO2D8PZ5mkR+AlO9hMudb2MqwmFb7VzwK24BITXBBHtwfhWxOZ465vSNsT
+/fdhuaJRZ/oPk+jfqosy7FXhzfcfnvGPJu0A41q6nxqV88nuimONKrfyf9E
DZZ/pscJ52k5/Xl9kG7KJRq1W3FB514f0pdpVOZlQQVVz0k70agKswK3t4+R
6wkb9CWfK5Lpo8ev0KjX6xT2KZ+k24NwRn6RVHYEGXemUVuidzGvaSDtQqNK
WhmWLN/ST893pVHrmL3XUpZ+ocevEcfLEDeH6166Pa7TqCtbYgbGr5NxD+L4
eSZZfa4Qdkh6mDTwncwnHOu39arZ6q9036BRq+xfGr0zIu1JHF/6hzfph5L2
olEFtr9b8rqGboo3jUqVtBzR/kvGCZ/lGK2vXD9Atw9x/I25ZWyzoZviS6OW
dLH6FCaR9qNRv5bfNlvXAfNkiKhncQ3S7U8cnyHpwpIadHsQNndS+XXXFQ4y
edEqmE/mB9CoTzS0824PwIuXmp710ftGzyes8ntQcy6QbkogjXri00UJlwoy
Tti79t+/sV9w7sOAd3ZrhxgeWjIUtM+MbspNGlXaaZ+6TDhs0ZU1spBGOohG
TdrGkdw3Q/oWjdqTaKtbofAfw0LMDcyJJ0mHEMeLpcIT9zC6PUKJ/fcqyPL4
S7hJ4Yeg6jTMEXrg1TL57wxrjz9wHTehm3Kb2B4DboU3oXD5M/v3uVXwX5HX
t4Km4K0eSlQb2R90h9GoTn0ho3uM4UdaP1PWhMAjmYf1mCvp9iCswJW/8NME
Gb9Do1o78BWVSg/T44RTWx2t44/Dnza1CLkG000Jp1FFY1Xqj5WTccLH/4a5
bxwn4xE0auSpccWlUiMMt1Yd/fjTkG4PwrzSBaFNN2GdQP5dOaWw/49L4wGj
sHmGTcv6JT/p9SJp1ESOei8+Tbo9CKtvdzP2MCXjUcTrZy+/ceQKvLzl5teG
LDKfcCHztjK1ajIeTaPqbfwelfWejBMes4x3EPoF347W2evPO8rwurrZVb9k
6abEEK/3n5zfZ3bDdoomrW3GpGNpVPaTXDm7ncj1hDNCX3g/CoG1Ks+ZrMok
8+No1P7xlZtCK2GvNU3cc+9giWPXBs5NwuX+a8t7uMcYNi3+EL1fhm4PwrP/
3XIs3gmrHhqRiL4EX350qO1yOszfP5fTXw4/Wpbnc7SbrB9Pox7ec8q0chwe
dubdrMw1zsgPyirnSZIiTcTlehwGuamk79KotVyrKq4a0U1JoFGtdryJ+X6B
jBOmpEwVv7sJR7OI9NSlIn+d1c6/z17Ata8sRTPbkX9KIWhH9AjpRBp1+lb+
Kb/FEwzL6M2mnNlKOonYf4WrqvWOkk6mUQ2F9nzZbQf/dLNjXe8D+3+4LS2R
AIvvLNLmK4Kf3us5S2mmm5JC7C9Wppsjg/CgtXTOhwWTdN+jUT3qdRobheHl
ay8Ml6yn24PIzwuN4snRgbXHS9bFnUF+r/7nI4HXyDhh56eLLrpEwZlXdZ8c
e0Xmp9Kou3qvtGt9JuOEu3fd/bXxD8y+eHALv+IUPT+NRk2x4TrBrEW3B+Gt
jSruY6Zk/D5xPVQyvPvpCmwTdrW0ORRmmkz5WJYJxx6rpTyshFWKf6xKeEc6
nbh+iizdHTxB9iNsfl3Vwp3rF8O/P5n42EqRziDOvxpe94/voJuSSaPKp2fQ
9hqSzqJRq9maBlUdYWO7cTaZQHI94Ymm5fKC9+AgZXUd1hJYMvz0uck2uGTK
/1b/D1jPKPdhK+s0w9+ftzZXitFNySbO76Izo/mqZJywyA3RpclH4IK+3RtC
bWAdrbP6173I9TnE+SDjlpN9PBkn7M5REGXyBOa373qq0wQ/aP7XpTYAa62X
/CNHmWH4Q8ReEWGhGUZ9p2n77WwqMPeJcNPpffD9F8+uD5yeYcynLv4xqd0d
bvdkqXwZAdt/ke0ryIVV6wdcvgj/Zpg5P41XwA92ktPfJJHym9Fv8B6L8doX
8ImVBTe2dv5mzN8UeTpda5yMPyDub3iXNupy/2H4cUDlmKks3R6EpZgvLLfV
gKPdV6lfOUnm5xLH+1TzaS9X+Op5j4CQCPjnoNLDuDxyPWFz849t6fVw27tb
vx9/hffoq4uXL5hluLjph2aDCKygfde2czPdlIc0akKFzu1+XcT51GYLf56D
vQuye2b94SnFE0xsqfDZdHaZZWVwj3jxgVXdqH8w9uxFxUm4YqlQzBbevwxv
CK4t1ZSH77M69x/RgoU8pNlNzUjnEe+PmXYlG3fY8ftGN89HsMHH8JrYQbjW
UOP7feZ/9PkIq7WM8z0WhXP339tctgUWf6lrUq8HL3yan9EXCA9l8U78KYeN
JcuFFvfAr++e38H/i25KPnG+ExQ7I75kjh4nTNx9BCoowtLs1/JUtemmPCLO
T16K7RqnYc6/PX8OX4OvOwWtMomBx0bU9pwtIOsRtjj7n93l13DH59iwG0Nk
/mMadc3aNT01TBTq//nD0OywDi8cnd62oHUl3R6Ej1jk8BvJI86+ylv6oyri
tdtuK13ThH0NEzav1CXzC2hUjUvZO0pMYabQp3tO2MLl2S8P/b5C+gmNeo3W
cizGm6xHxLf1fTypehv+/e+7Vcdd2GnTIudlRfDYuVX+R5vhvIC1oWM9qG+f
phZ9+xusUKGdtG4K/q9HP+M10wKGs6bN8+x5YGt+h6dcIqQLiff3uqvlOTJw
//7A2v0b4RSrqOahnXR7ED7lldoZcBAWTczvlTkB9xSXDtKssL5NdnyxRizc
EC0tW94Aazfv3PLvC1y9yHjvtjnYc/XZI+84mBim7nAycl0O/zvuZSa0Bi5x
Cj37VJmJMY9r2F3HY+qwam6Wy9Q+eOpV0Y2IY+T6IuL4/lIdsMECXrfyY8yF
q/ADvZnMvEjYzoH10aF7qCcXtLR4+CE8mC5eGVwC369SrFN4BUv82dNt8xlO
UDEfyvgDGx88P7ZnMTPDwjbuv7/yMzP6d/oEMPmuQjwyOZJ9zVpY78W9JdVb
4SVdecKn98DNEy8kmPRQ7xZvvVzyKTJOuN/0/I5ZN1jtwVK9Y1GwZduZDyxp
5PqnxP3EnyLrR4/IOOEXEuzjJ8vJ+DNif+w1vsrVBPM75i56/o7MJ7wjmhJm
/Q22KdMVEfgFR35NvV/FwsLw9w17n4uKw7u9frx2UYN/im2aUboAJ5Rck/ia
Ab/qa865UwhPsK/evLOabkoxcT5VuVwx/Abeb0TbH/8RTkm3PfXrNzw9yXNZ
V2Ahw7pKybRSL/iBtYqw/Ch8fKHb7k/SrAwvTqmyizKF179a9kvDDjb9aXVj
zIVuD8KBgsUcSX7wE3XOyAMRcO8ZU/E/KeT658T5ODgvKyMP3lzAtNGgFDZ/
p1fG3AAzd/u5FC9YxHBqZ/F6x82wTvSezx806PYgPHGsLVRHF44XNNtRfBLW
7PjxQ/ocPBzpGh/hCkcaLNrP7A+rC4TPOETAX9+KZ3xIIfuXEM8jrb4iOtyL
GbZp/h76zAVeEuqyQ9oPLj7EOhweDpvz3IlnSoE5Xovtd3hIt0fJ/PtvS8b+
OjinUXeh9BdYL/jj4/AxrJ/VsTNnorAxnMo5w+vABR9o8Cl7LwxP3Vxiv18G
TtifKPJsI6zFoVAvtZuN0W+47qlL+GE4MlBThskU+er7WtrP28Jf2U76vHeG
Q179t36/L9yrvfC2VDK8rlZ0eEEJ3FxzJOPpKOz40tv8vDQ7w6L9WqxT6+F6
JrYsdyrsvKr+APMBeA01eDTAiJ3xeraYHorgtUT8+lW+LVEXYIX41p6V1+Gu
4giP1Juwb9cxSfloeP20UG1+KukXxPYJ9Niq5sPBGxN4yl6Q/QkPXJA41tAO
78y7n9A1Ak/KPVScWMXBcGZaUQm3HmxQ7XIq4hTM3KfGInIOzlvwLz3FhW5K
KY1qIl6+X9YXLjLRuLMpEeaLq+3e/RT+5DMkkOvByXC+A+fR5Xu5GG6IXery
wAD+Wi2cuMsCpoysetnhSLcHYWEh2f/srsOHzm3eHBULe1doelU8gZ8u03v9
XzP846z5CoHv8OLwszuzZ8h+ZcT1rNTBirqIm+Ftg1eC3/LDBkuuP7aRgAMt
g+fCt8NlxXH7ywzh7v4URz1Lbka/Ce6sqG8XYe4t+S+u3YBlTj/tWxoC7wou
Y8uMh42LapTUs7gZ+8fpU6N+axHitzneulm/hHM29iT/bYFrTvbRwnrh3oCh
H9LD8O/Ho0tf/MH8axdTTg0I8DB82pg7h08Fvua7rOX+DtLlxP1rnsi02gH4
Ufdq0TfH4QYWeQ1La3jjgz09xQlwgr7FJZ63MMt1KuujhbwMq7Ye1O0Rh3X/
6js7roXtpE0SWLfBLiWnlN/sgn2PWFTH7YXDv1odszxMtwexPclutkPrjsGx
1Yeqk0vgMK4NCUsk+BhuFnvQZq8Gc6tIcdTrwQlO1cslTsCKz82lXMxIE/1L
5igbmq3oplQQ1yONxJ3S9rBt4zvjt65woMFyZy8/WDiu0Kc7GM78qHdHORxW
lRxP8o+Fa61v535MIvsTHhhtfBX8AGZ1Y/+iVgxrBHutiG6FPRNnj0x8h81z
nhywPLyE4Z3P7Pd2PoadZ41rCxrgvB3799z+AuuYVfrOjcKDnltqzv2DC5dO
fkllWcqwd2rewh52uimVxOu/0W7NUj5YvEZac58gPGzQZ3FjJdaXDCR4P10N
BzofTx2RhQ3ZBKql1sETcsHMEdvgUB2W3cx7YQV7N09Hfbg2ZKzioxkcKZ77
ScAatsg/u+Cg/VLG66Gya80qn0swpbWXWuIKL1E0qn4SAa/xe7PnYR6cdfdh
xrkieG1BMJtCKfy4ztZmqBpW/bS3PqOenIc4/nZyswav6YL3qVUeTPkKH7W+
xis2ARtHbG2JW8DPcG/28vXHF8NnKqfuLOehe/79NdTZNtG+DLYfeaQfIQJ7
7JXvurUZvnPvnrG/LtzD4WNjXwpLXbJ01pNbxrBpqoJetjEc2TamxBQCP/r+
9q5iBtzE8ozDqAJ+W6c8cI9G9/z7syc0q3K4Ee4zWJ2wpQ0eEol38e6GpzOC
1wkPwAs3Xh94OA5vO6NZxSolwPClCI5EE0M49MEwZ4AjnPPyjWtBIFx8pEp5
XxRc+75g8OM9+PU9xWq5LLrnz8ftZ+8nXs4j48T5/L2SmFt5Idw/GWXA8QJ+
c/SCWvw4XJqvI64oJ8hwQe+zsMuacBaP9MLSU/CadBN1c3s4ST38Cqs7bBqo
FN7pCYu01+VlBcDdqywb3UPhqHMLhg5GCTK2x0G28LEDy3KG932xuRrmCMul
KY2vToc5zkxYP+mBZ6vbV1/7BX+XfPZBa4kQw/16ctuyxeAe77gYHkW4U0Sv
tmI93FbA+eviVrhZ5+UaqZ1wQ/9Vvc49QoztCbZYRP3zCD7YHyovKiqM/dE2
oz/+BR6qMveofbCCYbHbnTa3Cuiev97rmR7U13sOB8hX7xCuhEunt8j11sIy
d9bM2bbDYYp8bb/6YNpv39IXQ/AsbTbDaxRWjrhwZ+80OQ9xP2hpPniVZw5u
nm3VjeMUYVgtqkxaWhjup9i7GRyGg2xEXvv4wu+3uzj1j8Fr+dpX7j65kuGh
KSOt9ttwWs97+7PVsOdrMebH7+FTlWZRs1Pw6+eeZsnMogyrP7knr8ULTykX
hEYLiDK290Fu9eSQCGwh//b49tWwSMaXshBZuDP47KCEMXzn4g/ewluwg6VS
2lw6fNDIccveCviFbhjzcCOsoPO4Mawb7q+tUvnSi3njNNuiNg/AupX9swE/
YPYdk2Y947CrbvCdTDkxhv87s+alkxmcen7U5L07bOzyYmp3NKx6bfXuX2kw
v1dASNZj2NOnZKN3Md3zzyc//UbemVTApoESnptr4YYgfRm+1/DWEP+mobdw
xu3nl6p7YIHwYeGEPrIf8XzkHbmq4soQPBatZ3VkFD4V58clPw033S1+zDJH
1pt/3mueUhhhEmc4qEW2tZYN/t1m7JLCCysbOOnw8MPWHSFi7oJ0zz//JRpm
jg0Kw+1dlS/1ReFbfbdMS7bAe34c/yWhD+eYv3/2MxDm7TzpXloOl0jlbXCm
wWcvU34oN8Hl8TKvbr3BfALVh9P+a4Pt/nO+od0JVy5JNkl7B6/I29m0/Bt8
6cBn9aApWMp/tfhFvlUMd1ZaLDiuAIc/5228oAkfKiiJvmkK5+SF/RO0hdkf
WFukXoElFD5cpbmuYmzPluyjUUNX4cNyr/K4bsDWmep167zhqHTZv06BcE0a
/7oXobBnQvmft5mwepQdbbgSjr+zS9HtNfw7ZPmdRT3wEp5bOXIfYdlbzDUH
PpPzE6ZyuXx0+AIbBg1P3xmEfQO75LuH4Sf+1abik3DGvvrlftNwLGdLy48/
cHBTZ5DeHNm/mLhfCv2o9ZxJgh4nbMn/o9ifDdaJ/r3WgBcWTFomOLoS/py+
bu6mPOxcZPm6QgvmpsUn/jKDu5qK/MLOw6ntLecVr8JR0V2y4R5w4PHevt9e
sLvIwF0zP/j8hx/HagPpnv955davi6mno8k4YcUMnt+v4mBxG4GCdYnwEoWV
9lEp8MLh1TL/0sh6T4nrhaNyfH0O3DypzhvzGK4q0qybK4QLXXS8LYvhDLWj
6o0v4Li/RtPrK8h+hD1uWNktqIUtF17ubWqCWVuXxW0ahNOSCvUTFqxm2LCY
/UA9C93zP3/mbDPVmF4El/94pLaGg8wnfGnRovW63HDP1oercvhhDftjvKwr
YP636T+eScP9atN15zbA3mwxPm8PwJIdW6jbreCJ7YErRy/C1andv1M9YOfS
tWNvvMh5C4nrVafnt3++ZJxw72h7r3wgHM4h32kYDGuvuf7aJxSeVW+teXSH
rPeEeD40lC79GAmfvuD2hDMWjjyf/rynHn5l11qR8xc2t/1WHS4gyfDs2Tma
uxL8Wta8NkYFTvlWXVu4EXbKlH7VqgrvPRv46qca3fO/f/o5eKhObhccab2s
3kIb/myV1NCpBytZyTfpmMEfzoqdf2ABB9kt5eW2JvsVEO+H84vy7W3hb45/
jry2h7Wu9N0JvQzfc69/e8QdNvGLM2oLgAXDbN8bRMFzJdnfTzWS/Qm/XqLA
cXnLGrofE9crd2VvXi1Y5+umv9m6sELcs2czhjDH4W1Oe07CrllX9ezN4SGW
MpWIM/DxkxS+Emu47tnOkc+2dM//vvTlqWOthxPIOOENz6PzryST8Xzi/LOs
OyQhFeZ3WGH/Mh32rjPW+Z4FT0gmyC3NhU9f/7h4az5Zn3BLl/jAqQJ41wbz
l35F8IIEK/XV1XD5onNFpc2w+rsrmZPf4Oe5nnEKzFIMD6xujGznhZfGCIZ5
iMKZrSUh+mvgHdzmwXIKcGD2Bs4IJbrnf7/9VnvRzTkVWPxrF5vNJtjWK8e/
bQtcdW7ndRl9eIVh+2V3B/jiLlu75ptwvQLltGQ6/Ct5n2lTAbxaMMLIuRK2
L7Dq/PwSfnZk67EDr2CWEc72ogb4UNBHPYlmcvsIx8o+ag1qhb/UeOv+aifz
H9Ko6yyOvTHrht0WyB1ueA9L8jw8v+k/uEFkQ0jSNJx0bypBfw6+LPcsl51V
muHec7GbzrDB+/LdSss46Z7//EPBhLGWMC8sqqredGkpPFZK+SArDNM0q358
EIdVAlIvb5GE4xt8/t6Rhll5rXyG5cj+ucTzwlFtrr1rYY1u9pX/NsBCZo0K
j9Vg79TcAq4d8PBAyDbrXaQfENcbecfqSk240l5XZ+VeWOHR+rYrOnDkJL9x
yyFyPsKULVN9CkdhW/cOWz8DmMoc67bNBOYPNL45ehq2TLOse3mNrJ9DnN8U
ZLtdfWCex/99UwqCXacaHANDyPXzn3/akjvTHwYfvBpyY0ck/LTcgS02Bg7a
s17oUBJs1jQpw5ION/B15JlmwZv0n6o+ewAnRceUL80n58km7ld7XLXtC+CK
WxZxrl9h550Hh32XyzD8+kq2c60oLJW7mJl9DXxk7+ZaORnYvf9M8H55OON6
uK7dWrhVuEowWJnu+c+TyR0RT2naDHv4XVXgVYdzJHJG1+2EO150Fx7RgJmM
2Nwv7CHrZxHP2xObd97ZB/ecGtMXOAYHNubYxJyGC63fKRVbwp+Y2Se7z8Kc
iarFf+zIfoRVt1pdF3GAT7+N0Nh+kczPJK43DtVspk5wMcd40zUX+Mv9VeGJ
7uR6wsJR4pWVUfBhP7GfXx7BtnOiflfKYd8roqJsTXD4+oRvb9rg5JGVT2Lf
wRmN74XnPpD9M2jU3Oy7Hqc/w08CTL7SvsAlVit1FL7BVZrv80O/w3Wr7wpO
jpD1CTcvMLlqNA53fBTpezEF98fF5/r+hceOibgeYpFleGZjz8fHi2AKf7zm
cg665z8fyTp2ItudG+ZqXsH3iQ8WDorryVwOy2ivyLggBpuqCrdHbIXDZYRY
nunDkuHr93EbwwVzB0JPm8PuG0+sv3UG1rC1bn9qjXk5ky+79NnCbe2eItzn
4YkHRRlP3eClPt83nPaHddcbHHiaDId9KjvD9Rw+Lti4WLUUljjQnW1eAQ95
DhwMrsZ8j55OjBbR4F2SPKpcTXBLiOw18zZ4zNKUnesTzKd+J7LoB3z4+2wu
5yI5hkNjLWlm4rCpboJYlBSswN5+pUEBXvp1dPWAEun7xPNoBVfzgvXw57uy
7iKb4FcumjKbt8CW3wo6kzVhJiPJAE5deJsq89AnG/iy4Od9RV5w7lR5dlA8
PPg2kdP8CeytyfOioQJe9eTauc1N8OLbsUK6b+ie/3zvT7vCl3ZtcId2i6Nf
B1wqObwypRsO6lnj1NELHw83aeIcgO0Da9bPLZBn2NNDKWZUBNZI7PlySBxe
VBqgkrsaruvZdJ1TGg7601dvI0f3/Oeb+baon5FWhiOdov/1bYaTRnWUTTTh
TLsFFu26cLNh69rn/vC0RtpMYilMUYnl+lYNLxILWaVSDwdGBGQbNMHcnN4b
3d7AYZ7XyhLbyPkJC8w4763ugCVbzR0N+uH1D3RiBn/Cu/w2Vbj+hQ+biX/j
ZFdg2PDgsr/6vPBJNXa+RAH4cz5LXJUQbCkzJzkoQvf858eHEmZyOcVh+2UT
qsqr4bGbw5X6UvBlpm86rrLwtHNfe4ICWZ+w+8j7U1VKsHdPyyXOTfDNVzR/
/W0wN7VyiesOOKywJD5hF1n/HrG/FIukqjTh2Hv5eQPasKhwzlZOHTg59H71
ukOkU4j9uyj5oL4unHE1rtNFn+xHWGEiwjzBEM6zCf1eeQLe8CnQacAU64uO
+VA4zeFSDVd+fWu4Rvm8TII93MZhdHidG9z3ZZdzpR/cnZfUwHwPbnH7J65Z
CitvDNz/oAIOHV7mtOwl5htJT066WgsfNFOs/1IPc7ZpiBe2wHVaxpd9u2D/
ZxfrDHphLYWbYtIDcNoXgX0hQzBLYsqlXz/g04ZrE0+OkvMlE/erfMWvaBOw
+q/Bi9ZMigwX9wiKsvHCQpH3tB2Xws6HlC52CcAdi5/f3SlMN4Xwpkqt2syV
8MQG05WukvCj9MsX9snDWRdaa25qwSnblVc0msGrPSOKfe3h1JoZI6ob3D+Y
LXv3BizJYToz4wdriGw2k7kJWyjyvjK4Rc6fRBz/6t/W+dyG0w5VRj8Oh786
XrLmjYOlwqVUzyXDWmlziXGpsGVh56K6dNiXln9+Ogu+3xnYIZVLzjNf//e2
dK8CWHrliFNvMay9tvYDdylsvSNZa3sF7H/YNde2Gs4wOyoQSyP7zX8/537R
k6NtcObQCn2uT3Ddn4kStX54iLNJ0mYAZhdND4oeguWUPCZqfpD9CO+jGhlP
/oRtjqhUr56AA805FHR/kesTiNf7Yv8dj99wzmxOy/jStQw/8LnMZ6UIZ+x4
HH1cC06d+Sl28CSc0h7SR7OFEx+vTd/pDH+wEVh+yo3u+e83iUr88792DTbp
+jITfwOOD220ee4N9+x58q7LD14xF68zHUjWv0tcTwu9XwjcgmPP2a3deBuO
3scxlnsXjpDOeiKTBfNHukSdyYPDWPa6pBTCLc/XDZU/g/kuLj/xsQQ+LEdp
+FtGzkc49NPANpEqmOdwkajRK/hWqS8l8jXcdNnesaAF5lI0+NzyFtbp3350
tJPsF09c3+PWVPP0wBzsk2k6n+FA52q/gEH4lVLOdPp/ZD3CiwfunK0ZhrUT
3Lr7R2E//dP7mSdhlV9j5pLySgx/iPZ01TSD996wLG+0hwvO7mM1cIdfn64S
fHodHjLZJivsBbMYPtnq7guL6a7V+RBAOo5G1dMSP58SCgduXRJmGQVPSkx1
DKfCpzi6V155BLsuPKrU9YTu+e8nRszVU9WewXkzGrp3S+C68Ren58rgLz82
XTargimDD32ramDhzzLRa+rgjT3JmX6NZH/Cv92Z97NS1jHcxbGpQlsIrtkQ
M9gjDBeYzPI4isApvic3LxSFQx9WmsaI0e0x//3MBQEPKiRg7aOHZr+tgSm/
3sVsVYCfxlpvvqkCO6hPtr1ThWU+37igsAMW4PgSU06FWTZoV+jtgseMswcH
d5PzEe714ea9qgmXdLSZpmnD0bJxDxr3wxPjWmleB8h60TTqodKx+C2H4Cz/
hPCRwzDr0X1Babpw6UCyG58BfNl9xuaqEdyslWa+/gSswHfk+Ddj2P/d7JFE
U7g/LWOv/ilyPsJxWylbKk7Duq+PyShawbkxzOJ91uT6KBqVzeKhYIwNbLH2
BM8hO7h8mnXRQnvYOdh0ysERVpIo/NJzCQ78bvY+zAn+Wsj1VtsZ3nXjWcM/
F8yTsP9MdYEbrN9b8lj8Osx5mf9ekCdcI/xm5fe78PXy4Oj9z+Ch9+XhM8Xo
Z/BnPDS9BK5YLh2sX0rmE1bYdDyAuRxmciy/cbIK7syWcn1eA+9+ZeR0thbO
/Rp0QbAOFmYpt39ZT/aLpFF9Vo3bXGyEf6pLWa16DRsbG51+3QzTXIJOXm2B
VaLKTsi3oX6Qp+H2uE/w13OjohwjcEnGMUGrMfhO3wueqkn4H2WUw/EX9oeN
qORisRn4rdoxlsbfMNUokOI2C2c7vZiV+QcLhP+cbp+DPfNXT3ovUGbM/6PJ
YFSFGa5me/HtFiscq7H68xAbvKd4pCWFF55QKqk6LgifPDBStlgIrrORKCkU
hjf66z+1EIGT0vwLlojSPf/9dafe4Rz7VfCBFfppdZJwzpnV7keVYfa8Ud2e
7XDKrjT/f1R4y1vDUnEN2DtBpStfE2624pzYtQcWUf7K3aYNW/8ukz2zj5w3
gjjfiElHZB6GaRq3KMMG8NTZSVsVE1gqxLjD6TRcuoqXK8YS1i+o2vX8LJx0
9a6Jji3Zn/B3rSvO7+1gVd4jd+ztYe8uudy58/Dn1TPe/u7wTnvaCb4AWEro
yOL3ITBndXdBRiR8PUbsJncsPGZvYXbpLpzT5asjnUjOG06jntHI3NydBHcK
DXNRU8l8wmHevDNjaWT8Do26f0SlPy0dZjmu/9owEy6tvlLMkQ0rx5aEOubC
qecXWHXkw4HCN5feewo7vOQvty+DDRwS7LbWwNtWyAixNsJTPvtYnjXBD3/a
jdg2w9YnQrpFW8jtISxRk//yTSscETcVt7kDXuyoduFuN9xWc7B+wyCcKGIu
2TAJO7zJuuDOpMIw1Xe8XIEHzugVHPReBvOpbeN5vwLOObJQ6OJKWMu6SYJN
DO69FqWQKE73/N+3cI04tWmjBJxbObbXbA38ecTbJFgG9jIS+P1jJyxZlR55
8AR8gVeercwKLjPJdVO6BC9RPhS9/wpsyfKzwMoV5rWnVk26kfMSftYR+sbr
KsyZrTyc6EHm36ZRC/k9ZxU9yTjhU9da2Eu8YPZBCaF9PvDjIxelO31h1jX8
GhMB8PHpglO8wTCL+cLzCbfIfqHE/qnXv6oQChtuvH+z+Da8IHEqRvsOrHch
qtAiEs7QVG31iIEPfnfhfJYIT4Y91xxNg3f1qj81ewSHKlbKtZT+v3qqJ9g8
y+Gy3RMDypVw+8Hgmk9V8LCRVNrtl+T2ERZxMDQfrYX3+waKHWmAMx4Nx/C2
wqwfdfmbu+DyzSvYDg3AbqF9fxsn4Kz7y54rTsOdJXucg//AP2m9Btv/wota
XTb++AeLfljCf5eynj5/CI266Vv2mA4TbDH3/mHOQvjOMt5znGxwlnjm/hJ2
uuf/Hk2l/C45O064a9O7xSLc8M+dlwbqeeDFB7hq3PhgMcP7qfJL4U2nd3i9
44cP2nea3RQg+9+iUd292cX+E4KzY7f17FsJL6YlGbBLwpbjLG9eycGmWRpN
xgqwgZl3/YgifHB5da2nEtmfsNZr5pplyrC67+6qDBUyP5iYd7tXudoGMh48
//usyhdNG2GpbKbnZpthASHPJ35bYVa/BXkPtsP/tu98QN0BT014ZLVS4eHs
8nTLXWT/IOJ5x5ySNrMbThX+d+v2Ydii5Y+zrAmskfv73OXTsGTgjHnFWZh/
2tlkwA5msZw+xuUAz4qo6ic5whOtV3TXX4S/BxYdqrkE9+38pWPkRM5POGVm
YtOoJ2yePyYeEALXsrkNb78NK5ozl4yFkfVuEte74psB6eHw9BL+Y8aRsKlt
vCRfNFxdJTn2MgaWE3lQ5hoHh1zaGKx0l+xHWKrdoIopFS7Z7DzzNguWCKXQ
AnNgv0H/8B25ZL1AYvupfOYTD2HdmBilzHx45b6suiVP4MHfxWfcn8LLSv++
kagh6xN2FfBN7KDBvfbc54JekfkBxPFJi9y6sx7OERNbPNUAX2lWuneyGd51
g6r+qhXu/Gx2Kb4bttfwyjr/CY5bVCMgMALX1i32KpmFd38UVDf9B5eOS83M
zcH/A3ZHEA0=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 11950.},
  PlotRange->{{0, 20}, {11951., 12164.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.389814226143858*^9, 3.389816284103058*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate an Estimate", "Section"],

Cell["\<\
The code below generates an estimate with the objective function constructed \
above. Note that the argument names in the last argument to pairwiseMSE do \
not have to match those above (though it is less confusing if they do). The \
names are only used in the replacement rule that is returned from \
pairwiseMSE. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"outputRules", " ", "=", " ", 
    RowBox[{"pairwiseMSE", "[", 
     RowBox[{"objective", ",", "dataArray", ",", " ", 
      RowBox[{"{", 
       RowBox[{"b1", ",", "b2"}], "}"}]}], "]"}]}], ")"}], " ", "//", 
  "Timing"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10.906`", ",", 
   RowBox[{"{", 
    RowBox[{"12166.`", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b1", "\[Rule]", "4.959522698112732`"}], ",", 
       RowBox[{"b2", "\[Rule]", "3.424665335294269`"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3898142790699615`*^9, 3.3898162966911583`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mseEstimate", " ", "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"b1", ",", "b2"}], "}"}], " ", "/.", 
   RowBox[{"outputRules", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.959522698112732`", ",", "3.424665335294269`"}], "}"}]], "Output",\

 CellChangeTimes->{3.3898142792402067`*^9, 3.3898162967913027`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Estimate Confidence Regions", "Section"],

Cell["\<\
Now with estimates in hand, we can use those to estimate various types of \
confidence regions. Be aware that the code that follows will potentially take \
a very long time to compute. \
\>", "Text",
 CellChangeTimes->{3.432875237354034*^9}],

Cell["\<\
The pointIdentifiedCR routine generates a point-identified confidence region \
estimate. By default it calculates a 95% confidence region, although that is \
configurable with the ConfidenceLevel option. The first option is the number \
of matches to consider in a subsample, the second is the number of subsamples \
to use to estimate the distribution of the estimator, the third is the point \
estimate, the fourth is the indexed objective function, the fifth is the list \
of parameters we are estimating, and the last two arguments are the data map \
and data array being used. Note that unlike confidence regions that are \
commonly calculated from asymptotic normal distributions, the confidence \
regions in pointIdentifiedCR are calculated using subsampling, a monte carlo \
technique, and thus might not contain the estimated value. There is no \
guarantee that any specific sample will be such that the estimated confidence \
regions (which are generated from subsets of the input data) are such that \
they cover the estimate created from the full sample. 

It is always a good idea, when doing a long computation, to have the computer \
periodically output its progress. This will prevent you, many hours into a \
computation, from wondering whether the computer entered an infinite loop \
hours ago, or is just still working. Here we tell it to output which \
iteration it is working on every 10 iterations. 

A set-identified confidence region can be estimated simply by changing \
\"pointIdentifiedCR\" to \"setIdentifiedCR.\" However, expect that to run for \
many hours. \
\>", "Text",
 CellChangeTimes->{{3.432875258566625*^9, 3.4328753759629927`*^9}, {
  3.432875534366485*^9, 3.432875646032823*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"pointIdentifiedCR", "[", 
   RowBox[{
   "3", ",", "200", ",", " ", "mseEstimate", ",", " ", "objective", ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"b1", ",", " ", "b2"}], "}"}], ",", " ", 
    RowBox[{"dataMap", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", " ", "dataArray", ",", 
    RowBox[{"asymptotics", "\[Rule]", "nests"}], ",", " ", 
    RowBox[{"progressUpdate", "\[Rule]", "10"}]}], "]"}], "//", 
  "AbsoluteTiming"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Iterations completed: 10\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898163372294493`*^9}],

Cell[BoxData["\<\"Iterations completed: 20\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898163721196194`*^9}],

Cell[BoxData["\<\"Iterations completed: 30\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389816410624987*^9}],

Cell[BoxData["\<\"Iterations completed: 40\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389816491971958*^9}],

Cell[BoxData["\<\"Iterations completed: 50\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898165440969105`*^9}],

Cell[BoxData["\<\"Iterations completed: 60\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389816578957037*^9}],

Cell[BoxData["\<\"Iterations completed: 70\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898166170818577`*^9}],

Cell[BoxData["\<\"Iterations completed: 80\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389816700141291*^9}],

Cell[BoxData["\<\"Iterations completed: 90\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898167577741632`*^9}],

Cell[BoxData["\<\"Iterations completed: 100\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898167928646207`*^9}],

Cell[BoxData["\<\"Iterations completed: 110\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389816826603134*^9}],

Cell[BoxData["\<\"Iterations completed: 120\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389816909251978*^9}],

Cell[BoxData["\<\"Iterations completed: 130\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389816985922224*^9}],

Cell[BoxData["\<\"Iterations completed: 140\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389817024798125*^9}],

Cell[BoxData["\<\"Iterations completed: 150\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389817062312067*^9}],

Cell[BoxData["\<\"Iterations completed: 160\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898171532528334`*^9}],

Cell[BoxData["\<\"Iterations completed: 170\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389817216804216*^9}],

Cell[BoxData["\<\"Iterations completed: 180\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389817254318158*^9}],

Cell[BoxData["\<\"Iterations completed: 190\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.389817289979437*^9}],

Cell[BoxData["\<\"Iterations completed: 200\"\>"], "Print",
 CellChangeTimes->{3.38981434427372*^9, 3.3898173809402323`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1084.1489296`10.48663393885403", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3.2000280597178`", ",", "6.303316732949135`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.626605119373968`", ",", "4.547069549856052`"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.7790625124921724`"}], ",", 
         RowBox[{"-", "1.6665026782639634`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11552775480654069`"}], ",", 
         RowBox[{"-", "0.24321077380972836`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.7979325727136164`"}], ",", 
         RowBox[{"-", "1.832279480282875`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.878475923044937`"}], ",", 
         RowBox[{"-", "1.933000220993107`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.006655859802456028`"}], ",", 
         "0.21779661630476435`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.32560671234847893`", ",", "0.9230768013960331`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08749508587329699`"}], ",", 
         RowBox[{"-", "0.12340820633532058`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.32560671234847893`", ",", "0.9230768013960331`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.8670314293562504`"}], ",", 
         RowBox[{"-", "0.16887244696827197`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.8951164849094613`"}], ",", 
         RowBox[{"-", "1.2610806265122723`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5235775377528757`", ",", "0.7577494077571092`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30243559035803175`"}], ",", "2.7287822174822467`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10547803075813753`"}], ",", 
         RowBox[{"-", "0.7015111704202602`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.8854510892894973`", ",", "0.11545268033258271`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.7403859418709038`", ",", "0.6511892496960942`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.32560671234847893`", ",", "0.9230768013960331`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.7067636573540674`"}], ",", 
         RowBox[{"-", "0.3610930073931369`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0330992878974596`"}], ",", 
         RowBox[{"-", "1.854937157763945`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.4972880300054943`", ",", 
         RowBox[{"-", "0.218954768327171`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5719512409758942`"}], ",", 
         RowBox[{"-", "0.521728736924774`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2036228583691937`"}], ",", 
         RowBox[{"-", "2.441764150701624`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.028601379833229426`"}], ",", 
         RowBox[{"-", "0.04609731235298181`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26308421154962763`"}], ",", 
         RowBox[{"-", "0.5263225072579752`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14459856174922434`"}], ",", "2.7452975380622635`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15455506309590442`"}], ",", 
         RowBox[{"-", "0.086173737872846`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.7839244592907963`"}], ",", 
         RowBox[{"-", "1.9326771789189052`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.7007044766834094`", ",", "0.800300964893104`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.7979325727136164`"}], ",", 
         RowBox[{"-", "1.832279480282875`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07004129794988435`"}], ",", 
         RowBox[{"-", "0.3155122826187011`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.039580428619242033`"}], ",", 
         RowBox[{"-", "0.18982946615870067`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9687036803289788`"}], ",", 
         RowBox[{"-", "0.45752531195654844`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.028965593931715855`"}], ",", 
         RowBox[{"-", "0.020660527442327343`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.028965593931715855`"}], ",", 
         RowBox[{"-", "0.020660527442327343`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10884858290517876`"}], ",", 
         RowBox[{"-", "2.4181465760898946`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.372502159470299`", ",", 
         RowBox[{"-", "0.4258694095842464`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9687036803289788`"}], ",", 
         RowBox[{"-", "0.45752531195654844`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10884858290517876`"}], ",", 
         RowBox[{"-", "2.4181465760898946`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23144873977138666`"}], ",", 
         RowBox[{"-", "0.32719459602393386`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.039580428619242033`"}], ",", 
         RowBox[{"-", "0.18982946615870067`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10033717240937351`"}], ",", 
         RowBox[{"-", "0.17043604888324934`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.960761225531414`"}], ",", 
         RowBox[{"-", "0.45839442659601315`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5014564499433022`", ",", "0.949594185761525`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.9983713673076119`", ",", "0.192162769049013`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.967209469012105`", ",", "0.7965911687331003`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"3.226043914467296`", ",", "1.6729366526439422`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"3.7907162858831462`", ",", 
         RowBox[{"-", "0.08377874457049483`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07004129794988435`"}], ",", 
         RowBox[{"-", "0.3155122826187011`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.024276172541586195`", ",", 
         RowBox[{"-", "0.04523418660595064`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.2618922136445243`"}], ",", "0.03360378028167519`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14096105086467683`"}], ",", 
         RowBox[{"-", "0.33624614732238456`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.4750437046497897`"}], ",", 
         RowBox[{"-", "1.5741832251385024`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1751638762127855`"}], ",", 
         RowBox[{"-", "2.5375630004819714`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.8669665774058049`"}], ",", 
         RowBox[{"-", "0.9075955379326431`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.8256991064501498`", ",", 
         RowBox[{"-", "0.02586070252843674`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15455506309590442`"}], ",", 
         RowBox[{"-", "0.086173737872846`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15455506309590442`"}], ",", 
         RowBox[{"-", "0.086173737872846`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.447625445375813`", ",", 
         RowBox[{"-", "0.03208612898441408`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.7790625124921724`"}], ",", 
         RowBox[{"-", "1.6665026782639634`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10547803075813753`"}], ",", 
         RowBox[{"-", "0.7015111704202602`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.1707798632154816`"}], ",", 
         RowBox[{"-", "0.9089366862623813`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.7907162858831462`", ",", 
         RowBox[{"-", "0.08377874457049483`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.9467498478512577`"}], ",", 
         RowBox[{"-", "0.8885375483248485`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5195195362395578`"}], ",", 
         RowBox[{"-", "0.45821212736907396`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5235775377528757`", ",", "0.7577494077571092`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.0752991645894034`", ",", "0.0602696157334979`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0008889658443647`"}], ",", 
         RowBox[{"-", "0.1261822624756047`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07004129794988435`"}], ",", 
         RowBox[{"-", "0.3155122826187011`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.2618922136445243`"}], ",", "0.03360378028167519`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.7212290334465177`", ",", 
         RowBox[{"-", "0.10150757735657204`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.751911781560389`"}], ",", 
         RowBox[{"-", "1.6917090139705264`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.751911781560389`"}], ",", 
         RowBox[{"-", "1.6917090139705264`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.0006672979482400982`"}], ",", 
         RowBox[{"-", "0.061116140841361924`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.7348267251289844`"}], ",", "0.040859056027346775`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.039580428619242033`"}], ",", 
         RowBox[{"-", "0.18982946615870067`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.006655859802456028`"}], ",", 
         "0.21779661630476435`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14786725571196324`"}], ",", "0.13680363349527042`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.006655859802456028`"}], ",", 
         "0.21779661630476435`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5610751419141776`"}], ",", 
         RowBox[{"-", "0.3667637256729388`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.6797578480076917`"}], ",", 
         RowBox[{"-", "0.6295938095968663`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.8951164849094613`"}], ",", 
         RowBox[{"-", "1.2610806265122723`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9687036803289788`"}], ",", 
         RowBox[{"-", "0.45752531195654844`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.8854510892894973`", ",", "0.11545268033258271`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"3.226043914467296`", ",", "1.6729366526439422`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.0409023643446798`", ",", "0.43077217057531325`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.006655859802456028`"}], ",", 
         "0.21779661630476435`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5719512409758942`"}], ",", 
         RowBox[{"-", "0.521728736924774`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.7790625124921724`"}], ",", 
         RowBox[{"-", "1.6665026782639634`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1029295803722568`"}], ",", 
         RowBox[{"-", "0.0303698658933839`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.3712652285709502`"}], ",", 
         RowBox[{"-", "0.016310860817246628`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.218426015604871`"}], ",", 
         RowBox[{"-", "1.7692654721532939`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.282331881042011`"}], ",", 
         RowBox[{"-", "0.22315239534482711`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08749508587329699`"}], ",", 
         RowBox[{"-", "0.12340820633532058`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.7016420701810487`"}], ",", 
         RowBox[{"-", "0.49755480081109305`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.9612849345904553`"}], ",", 
         RowBox[{"-", "1.7483272472293752`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5519990395728059`", ",", "1.0108549111781644`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9125472469888337`"}], ",", 
         RowBox[{"-", "1.1708362090455198`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.32560671234847893`", ",", "0.9230768013960331`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.1707798632154816`"}], ",", 
         RowBox[{"-", "0.9089366862623813`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.7016420701810487`"}], ",", 
         RowBox[{"-", "0.49755480081109305`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1333152548071703`"}], ",", 
         RowBox[{"-", "0.004458409638971023`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.4972880300054943`", ",", 
         RowBox[{"-", "0.218954768327171`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.1505890340772833`"}], ",", "0.5153256870197981`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11552775480654069`"}], ",", 
         RowBox[{"-", "0.24321077380972836`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.282331881042011`"}], ",", 
         RowBox[{"-", "0.22315239534482711`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.931103300252488`"}], ",", 
         RowBox[{"-", "1.5994952767058566`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0008889658443647`"}], ",", 
         RowBox[{"-", "0.1261822624756047`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0330992878974596`"}], ",", 
         RowBox[{"-", "1.854937157763945`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.9094101919131163`"}], ",", 
         RowBox[{"-", "0.12395836264540386`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.039580428619242033`"}], ",", 
         RowBox[{"-", "0.18982946615870067`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.4985791398797996`", ",", "1.719368613913031`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.6752959696020733`"}], ",", 
         RowBox[{"-", "1.8308147663702623`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0752991645894034`", ",", "0.0602696157334979`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9687036803289788`"}], ",", 
         RowBox[{"-", "0.45752531195654844`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.3373841883773014`"}], ",", 
         RowBox[{"-", "0.25963958396184433`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.7007044766834094`", ",", "0.800300964893104`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.039580428619242033`"}], ",", 
         RowBox[{"-", "0.18982946615870067`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2476407069321901`"}], ",", 
         RowBox[{"-", "0.22387030926726031`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.967209469012105`", ",", "0.7965911687331003`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15455506309590442`"}], ",", 
         RowBox[{"-", "0.086173737872846`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.967209469012105`", ",", "0.7965911687331003`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.006655859802456028`"}], ",", 
         "0.21779661630476435`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2786114290996889`"}], ",", "0.1963941742719681`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.9618044603162392`", ",", "1.8925243658722588`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.0008889658443647`"}], ",", 
         RowBox[{"-", "0.1261822624756047`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7403859418709038`", ",", "0.6511892496960942`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.028965593931715855`"}], ",", 
         RowBox[{"-", "0.020660527442327343`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5932373053405324`", ",", 
         RowBox[{"-", "1.021587347426006`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26308421154962763`"}], ",", 
         RowBox[{"-", "0.5263225072579752`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.7212290334465177`", ",", 
         RowBox[{"-", "0.10150757735657204`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10033717240937351`"}], ",", 
         RowBox[{"-", "0.17043604888324934`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.282331881042011`"}], ",", 
         RowBox[{"-", "0.22315239534482711`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08749508587329699`"}], ",", 
         RowBox[{"-", "0.12340820633532058`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10033717240937351`"}], ",", 
         RowBox[{"-", "0.17043604888324934`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.7868361038445197`", ",", "0.7660869251569035`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2036228583691937`"}], ",", 
         RowBox[{"-", "2.441764150701624`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2679929756765238`", ",", "0.43342937882723614`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.7979325727136164`"}], ",", 
         RowBox[{"-", "1.832279480282875`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9687036803289788`"}], ",", 
         RowBox[{"-", "0.45752531195654844`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.1240298165376275`"}], ",", 
         RowBox[{"-", "0.17668901619883548`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.1240298165376275`"}], ",", 
         RowBox[{"-", "0.17668901619883548`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.854794617897792`"}], ",", 
         RowBox[{"-", "1.9685979120476627`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.0409023643446798`", ",", "0.43077217057531325`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.5932373053405324`", ",", 
         RowBox[{"-", "1.021587347426006`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.09139038134757287`", ",", "0.03366198486313022`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.03453898680821752`", ",", 
         RowBox[{"-", "2.4031310948838396`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15455506309590442`"}], ",", 
         RowBox[{"-", "0.086173737872846`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.7868361038445197`", ",", "0.7660869251569035`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.6797578480076917`"}], ",", 
         RowBox[{"-", "0.6295938095968663`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1234738365515436`"}], ",", 
         RowBox[{"-", "0.06442825424752983`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.8669665774058049`"}], ",", 
         RowBox[{"-", "0.9075955379326431`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2036228583691937`"}], ",", 
         RowBox[{"-", "2.441764150701624`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08749508587329699`"}], ",", 
         RowBox[{"-", "0.12340820633532058`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6531705125598712`", ",", "0.9698716257722787`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5195195362395578`"}], ",", 
         RowBox[{"-", "0.45821212736907396`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19436415060153253`"}], ",", 
         RowBox[{"-", "2.613907919920644`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.3373841883773014`"}], ",", 
         RowBox[{"-", "0.25963958396184433`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.028965593931715855`"}], ",", 
         RowBox[{"-", "0.020660527442327343`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.7868361038445197`", ",", "0.7660869251569035`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1976806177935889`"}], ",", 
         RowBox[{"-", "0.035075664535007614`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.9094101919131163`"}], ",", 
         RowBox[{"-", "0.12395836264540386`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.174636133916864`", ",", "1.2256137714658328`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.5014564499433022`", ",", "0.949594185761525`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14096105086467683`"}], ",", 
         RowBox[{"-", "0.33624614732238456`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.0409023643446798`", ",", "0.43077217057531325`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10884858290517876`"}], ",", 
         RowBox[{"-", "2.4181465760898946`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.8315208964676852`", ",", 
         RowBox[{"-", "0.15488462114247087`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.1707798632154816`"}], ",", 
         RowBox[{"-", "0.9089366862623813`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.282331881042011`"}], ",", 
         RowBox[{"-", "0.22315239534482711`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.8669665774058049`"}], ",", 
         RowBox[{"-", "0.9075955379326431`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1382774809713992`"}], ",", 
         RowBox[{"-", "0.19009977557941354`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.0381839099273296`"}], ",", 
         RowBox[{"-", "0.8919590441421122`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.9687036803289788`"}], ",", 
         RowBox[{"-", "0.45752531195654844`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27737798360189`"}], ",", 
         RowBox[{"-", "0.3129476507465143`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.90427391838763`", ",", 
         RowBox[{"-", "0.04814439530343315`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5014564499433022`", ",", "0.949594185761525`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.028601379833229426`"}], ",", 
         RowBox[{"-", "0.04609731235298181`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.468099598307934`"}], ",", "0.16623945456883205`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10547803075813753`"}], ",", 
         RowBox[{"-", "0.7015111704202602`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.4750437046497897`"}], ",", 
         RowBox[{"-", "1.5741832251385024`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.7868361038445197`", ",", "0.7660869251569035`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.5014564499433022`", ",", "0.949594185761525`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11552775480654069`"}], ",", 
         RowBox[{"-", "0.24321077380972836`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1029295803722568`"}], ",", 
         RowBox[{"-", "0.0303698658933839`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.9063996357330333`"}], ",", "1.441884463974494`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.9094101919131163`"}], ",", 
         RowBox[{"-", "0.12395836264540386`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.4972880300054943`", ",", 
         RowBox[{"-", "0.218954768327171`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.931103300252488`"}], ",", 
         RowBox[{"-", "1.5994952767058566`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07766892205180793`", ",", "0.02104302547348695`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2.2230607648296794`", ",", 
         RowBox[{"-", "0.04258123280803862`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.447625445375813`", ",", 
         RowBox[{"-", "0.03208612898441408`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.282331881042011`"}], ",", 
         RowBox[{"-", "0.22315239534482711`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.8315208964676852`", ",", 
         RowBox[{"-", "0.15488462114247087`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.372502159470299`", ",", 
         RowBox[{"-", "0.4258694095842464`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.34742650871148645`", ",", "0.7700186010413489`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30243559035803175`"}], ",", "2.7287822174822467`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.9618044603162392`", ",", "1.8925243658722588`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.1382774809713992`"}], ",", 
         RowBox[{"-", "0.19009977557941354`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.34742650871148645`", ",", "0.7700186010413489`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.7979325727136164`"}], ",", 
         RowBox[{"-", "1.832279480282875`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.022206345313504898`", ",", 
         RowBox[{"-", "0.145610758447712`"}]}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3898155035006065`*^9, 3.3898173811505346`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pointsInCR", " ", "=", " ", 
  RowBox[{"sampleSetIdentifiedCR", "[", 
   RowBox[{
   "3", ",", " ", "100", ",", " ", "1000", ",", " ", "mseEstimate", ",", " ", 
    "objective", ",", 
    RowBox[{"{", 
     RowBox[{"b1", ",", "b2"}], "}"}], ",", 
    RowBox[{"dataMap", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", " ", "dataArray", ",", 
    " ", 
    RowBox[{"asymptotics", "\[Rule]", "nests"}], ",", 
    RowBox[{"progressUpdate", "\[Rule]", "10"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Iterations completed: 10\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.389817465722142*^9}],

Cell[BoxData["\<\"Iterations completed: 20\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.389817506220376*^9}],

Cell[BoxData["\<\"Iterations completed: 30\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.389817536924526*^9}],

Cell[BoxData["\<\"Iterations completed: 40\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.38981756891052*^9}],

Cell[BoxData["\<\"Iterations completed: 50\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.389817643587901*^9}],

Cell[BoxData["\<\"Iterations completed: 60\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.3898177106242943`*^9}],

Cell[BoxData["\<\"Iterations completed: 70\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.3898177731241646`*^9}],

Cell[BoxData["\<\"Iterations completed: 80\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.3898178078140464`*^9}],

Cell[BoxData["\<\"Iterations completed: 90\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.3898178442664623`*^9}],

Cell[BoxData["\<\"Iterations completed: 100\"\>"], "Print",
 CellChangeTimes->{3.3898156162427216`*^9, 3.389817909680523*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3.856319048456296`", ",", "2.1454956980695106`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.6022320597157655`", ",", "3.946342073678906`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.758515320566685`", ",", "3.873472629110742`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.121975581229292`", ",", "3.2001358400450672`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.30861764161801`", ",", "2.8643292563699294`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.229636229547234`", ",", "4.009271099936061`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.222296506606436`", ",", "3.7021413631708264`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.667326052247489`", ",", "3.50216145583092`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.10308368195788`", ",", "2.206103103363598`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.071180758798031`", ",", "2.4535117228456045`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.777957032682456`", ",", "2.580565610257765`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.492168038388647`", ",", "2.2233368743108355`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.4560397225760795`", ",", "4.191786700043076`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.008409118936321`", ",", "3.927436393051633`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.420578679072207`", ",", "3.279641598616092`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.67438565080357`", ",", "2.7902048629085052`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.072546683198437`", ",", "4.3154302339015835`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.616699630549295`", ",", "2.738693450149586`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.68132371336077`", ",", "3.5867294428437817`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.1588489521495005`", ",", "2.6502946290430964`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.36185329363392`", ",", "2.7562481316683956`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.39292361892197`", ",", "2.756119682217584`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.284823912845602`", ",", "3.9714956894435915`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.7065863463961097`", ",", "5.245094941926188`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.513622694863988`", ",", "2.4462173181216853`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.111645771185197`", ",", "2.4348325295475224`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.756055054697149`", ",", "2.513151278594024`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.348689648083395`", ",", "3.7401257487854185`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.384692125220825`", ",", "3.759755959607471`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.957668359666678`", ",", "2.931778240554263`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.7641095639121573`", ",", "2.8315182947713184`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.8626353499245902`", ",", "2.3871015026121`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.973781182635234`", ",", "3.338585390232176`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.9550865054735205`", ",", "4.330859326041393`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.9677091393272432`", ",", "3.4583018761633264`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.5025402591452846`", ",", "4.858317503714091`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.763320788532167`", ",", "4.929496632265756`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.392306635591315`", ",", "2.0244365509212523`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.496846066609061`", ",", "3.3514525034038902`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.252232445758108`", ",", "2.4819859275406335`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.5803901388565675`", ",", "4.2902877324152735`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.677159610224126`", ",", "4.413565390266808`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.71651063184852`", ",", "3.690286651631327`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.104717204167613`", ",", "5.659682543133758`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.938018671992935`", ",", "4.791758281612728`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.547843748528755`", ",", "4.4864195647532314`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.465906398725002`", ",", "3.3778710938896483`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.004709707461208`", ",", "3.3874634282116207`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.160508280357718`", ",", "3.7840386918240503`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.278028433400053`", ",", "4.802153018395292`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.913615751402475`", ",", "5.606508921205509`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.151468092885514`", ",", "3.994741757348361`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.452331991931021`", ",", "3.0402575707505974`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.582481878150439`", ",", "4.130659688197303`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.761595334782143`", ",", "3.704139811549106`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.986143665352249`", ",", "3.7937213829328056`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.4151114917853254`", ",", "3.527815771093222`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.286742948594781`", ",", "4.808993856735876`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.185590227371059`", ",", "3.115960081702263`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.280590111227801`", ",", "2.3053614976523056`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.529792019395204`", ",", "4.171566079719046`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.474961282834608`", ",", "2.623447496524918`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.963984726607498`", ",", "4.190857496584582`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.148706333079009`", ",", "2.355803270458024`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.093296348624772`", ",", "3.5030301813175235`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.1992647973769115`", ",", "4.251009682465427`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.873153533462063`", ",", "4.423754554181881`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.695005775447386`", ",", "4.746348002275454`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.480442021236764`", ",", "3.4477910634564073`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.8594696621747`", ",", "4.212085901303807`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.88680908259879`", ",", "2.827832502675812`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.878265969639579`", ",", "3.2332560046950967`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.437131412938038`", ",", "4.107852108096554`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.688986622033939`", ",", "3.8837554914581593`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.9839648943770545`", ",", "4.032020127151062`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.6132987602724285`", ",", "4.030990414268717`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.684250385634259`", ",", "4.750807723527456`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.053080950905849`", ",", "3.4834480696321655`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.064152413705756`", ",", "3.5894076411770266`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.191075098442723`", ",", "4.394709022518651`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.543610249870976`", ",", "3.064659902408837`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.34264832915847`", ",", "3.891206368715391`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.55768101777976`", ",", "2.6051054578697483`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.276185693896721`", ",", "2.366966110713448`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.350619740049667`", ",", "4.294420348830938`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.249807080272559`", ",", "3.485953813979061`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.919136406051139`", ",", "2.928790873700082`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.166202576505842`", ",", "3.9924482468777365`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3898160920268655`*^9, 3.3898183931557264`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "pointsInCR", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwVkmlYzAkAxmuapmOu/8y/maaZaaZQPZVWSxHFvqWkWlaTo01LhUqXpGXZ
lCSZ1tFl6VZS0cVoWKIlrM4tY3cjkpSrU0bEM8u2H97nfX5f3i+/1zxkm2wL
RUtLy386/7dTolnH9YcsJK/VK/9orY0XfptT68KFeOpi2CbKYqNY0SgJPGCO
mp7fF/RpWNhofcHmZYIAVpTGe09zDeDSt3YpzYWD2zX6P1oM0eCdltRkMSzG
oLEmMNGAAP2YnqJkgEDqiyRvTSETb9aVNVWtMYftg/MLo6kMOPF+lZve18dk
mHuISbk2IjIf5w8sJ3CjjX2z9ZQO2lLC5a4LWXAbsj7+pYwKY+Ld808fOPD6
5mH35hZtZGT8RmpUJsibymzYdJuAv2dkaIG+ERYtSL+zKZINGAbZVdeawsRN
91q9iyGWbByxzFIIsaYyYHStjAYWL6nGy1uMHFHVLK2lHMRXlor27eIizSdT
/OCVLpoSI0eqr0hgN3TbofgCA8sGduTKPAwgMyir6pinC6uYn6rkcaaYH2Gg
amPQYB5SnxmQxcHCwe7dh6b5hLVzf+VMU4wOzz1UfIcN9yxGI7+CCaVaavvp
kxFCFdkiNZOPg2MlIT2ZOsh61efuF2cEqqXdHvkeHazL7faZRyNBUTSwxoVU
lEzwdqQpzDBYt41xd5iJ0vCUhhE5B05lDWOfSBauXK3XqfiLRF5snOXyeD2Y
7S/Y/VzMgvfhVYS6nIYzW5oCa17QcLBgTnWzQAdFKepBy+dS3MvrdI1SGmJ1
bNhcikqKLEVKS7uMg2X5dO8n19ngyo/OzjtHh1Pny9e5FAlcLU41D8WQYG7V
vD/NFMHPh/eh4zKJc29Xnt0+kw43D/9W+lwt9O48mh/y2QyJ15JX/9FpiADb
9u1ZVEMUBUhjRY904LP4eauvjAuvwndzXK05OFgTVKmKYGJFV1rd3goOVgoP
v6/v5aPsI4OiTJ3+z+sCzaJIAU5rc1Upp/kY1yR8SLshwrH47tomGxJ6XwrU
/9pzUfMlYsr47fQezzKT38tD91OFZ78uHXwjSbGKKoBeKjX6oAkdGYnrlweW
CVC0s5+85MFC1xK/hItiHiZz7uWGOZLwlTsOpFeQWLdYWU1E87H+rGrhkRVm
6J5fZOM8yYZabC6x7+QhSFZ7LE6mj6i1WYSzjTn4PUsq2lIJnL/YeKaPLoXa
9yLTqJSJO8HSM50TJOSVtSfTv2fB1cfno4WMjmj33N0fnBhQe6dPFFuYoDVY
+SzchYQXsfoHeqMR3kbW70kY1cflBYU6flIOYj7HbAjeToFqPLs9WcLHLI2S
WldHYFHGDAS+4KH/7n5DlYaK8r1DnZJHJHpFzRaxtwg4mPN2LzspQEFEdkjd
AwpGLk+R8o1iCDyZ5x1oDGx8PYfLaBdgS3VZrb42B5NRVydFidOepxovjVzg
YP93xMm6u3xo/Z1T7qbhQuS/9PPUMA/ag1Y/k8fpmH23qksQS+Ko7Su63UMC
6kWSWuPDxlDsqj4TWkzDFZsUK/8UKSr5n2XKXgMwv/E439lnhqW+8c2xMQQU
nAPK1JtCSFpsQ8c4bKjonok54yT+Ua5/1mJGIMNecIIaz8c8QZK6QUpA9i13
RvU1IXrl4dfva5E4cmVVT8B8ApFkiq7wCR37VuTbXnAVQzaxM0B0mYG+jDb7
s7cEiCoU532Vw0Fkr59N5WwudKu+3hp1QB80ttShb4Mpmt9pOuzN2XB4lN1A
OAvBjb+Z5tpNxarTtlFdQh42GJSO/jJOQUnwjsf6YTyM6VqmJdhx8KdvUHTH
FyMcx/0bzgN0PHPkCubWiHBruOeVdYweKI7MZMEaM6iSeuoPvWHjPyROR0M=

     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{3., 2.},
  PlotRange->{{2.8626353499245902`, 8.758515320566685}, {2.0244365509212523`, 
   5.659682543133758}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.389816092617715*^9, 3.3898183935262594`*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Evaluator->"Local",
WindowSize->{915, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (March 13, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 49, 0, 76, "Title"],
Cell[642, 25, 34, 0, 46, "Subtitle"],
Cell[CellGroupData[{
Cell[701, 29, 47, 0, 67, "Section"],
Cell[751, 31, 63, 0, 26, "Text"],
Cell[817, 33, 121, 2, 27, "Input"],
Cell[941, 37, 136, 3, 27, "Input"],
Cell[1080, 42, 380, 10, 43, "Input"],
Cell[1463, 54, 212, 4, 41, "Text"],
Cell[1678, 60, 81, 1, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1796, 66, 28, 0, 67, "Section"],
Cell[1827, 68, 327, 5, 41, "Text"],
Cell[2157, 75, 85, 2, 27, "Input"],
Cell[2245, 79, 77, 2, 27, "Input"],
Cell[2325, 83, 470, 14, 27, "Input"],
Cell[2798, 99, 452, 14, 27, "Input"],
Cell[3253, 115, 411, 12, 27, "Input"],
Cell[3667, 129, 411, 12, 27, "Input"],
Cell[4081, 143, 419, 12, 27, "Input"],
Cell[4503, 157, 453, 13, 27, "Input"],
Cell[4959, 172, 1354, 38, 89, "Text"],
Cell[6316, 212, 809, 26, 43, "Input"],
Cell[7128, 240, 700, 18, 43, "Input"],
Cell[7831, 260, 483, 7, 56, "Text"],
Cell[8317, 269, 386, 11, 27, "Input"],
Cell[8706, 282, 166, 4, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8909, 291, 70, 0, 67, "Section"],
Cell[8982, 293, 2371, 52, 137, "Text"],
Cell[11356, 347, 131, 3, 27, "Input"],
Cell[11490, 352, 151, 4, 27, "Input"],
Cell[11644, 358, 731, 11, 86, "Text"],
Cell[12378, 371, 10778, 257, 718, "Input"],
Cell[23159, 630, 94, 2, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23290, 637, 47, 0, 67, "Section"],
Cell[23340, 639, 465, 9, 56, "Text"],
Cell[23808, 650, 263, 7, 27, "Input"],
Cell[24074, 659, 1383, 38, 103, "Input"],
Cell[25460, 699, 334, 13, 26, "Text"],
Cell[CellGroupData[{
Cell[25819, 716, 146, 4, 27, "Input"],
Cell[25968, 722, 167, 3, 27, "Output"]
}, Open  ]],
Cell[26150, 728, 241, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[26416, 736, 232, 6, 27, "Input"],
Cell[26651, 744, 13840, 233, 234, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40540, 983, 39, 0, 67, "Section"],
Cell[40582, 985, 339, 6, 41, "Text"],
Cell[CellGroupData[{
Cell[40946, 995, 284, 8, 27, "Input"],
Cell[41233, 1005, 362, 10, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41632, 1020, 213, 6, 27, "Input"],
Cell[41848, 1028, 177, 4, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42074, 1038, 46, 0, 67, "Section"],
Cell[42123, 1040, 251, 5, 41, "Text"],
Cell[42377, 1047, 1729, 27, 206, "Text"],
Cell[CellGroupData[{
Cell[44131, 1078, 510, 13, 43, "Input"],
Cell[CellGroupData[{
Cell[44666, 1095, 123, 1, 20, "Print"],
Cell[44792, 1098, 123, 1, 20, "Print"],
Cell[44918, 1101, 121, 1, 20, "Print"],
Cell[45042, 1104, 121, 1, 20, "Print"],
Cell[45166, 1107, 123, 1, 20, "Print"],
Cell[45292, 1110, 121, 1, 20, "Print"],
Cell[45416, 1113, 123, 1, 20, "Print"],
Cell[45542, 1116, 121, 1, 20, "Print"],
Cell[45666, 1119, 123, 1, 20, "Print"],
Cell[45792, 1122, 124, 1, 20, "Print"],
Cell[45919, 1125, 122, 1, 20, "Print"],
Cell[46044, 1128, 122, 1, 20, "Print"],
Cell[46169, 1131, 122, 1, 20, "Print"],
Cell[46294, 1134, 122, 1, 20, "Print"],
Cell[46419, 1137, 122, 1, 20, "Print"],
Cell[46544, 1140, 124, 1, 20, "Print"],
Cell[46671, 1143, 122, 1, 20, "Print"],
Cell[46796, 1146, 122, 1, 20, "Print"],
Cell[46921, 1149, 122, 1, 20, "Print"],
Cell[47046, 1152, 124, 1, 20, "Print"]
}, Open  ]],
Cell[47185, 1156, 28671, 752, 763, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75893, 1913, 529, 13, 43, "Input"],
Cell[CellGroupData[{
Cell[76447, 1930, 124, 1, 20, "Print"],
Cell[76574, 1933, 124, 1, 20, "Print"],
Cell[76701, 1936, 124, 1, 20, "Print"],
Cell[76828, 1939, 123, 1, 20, "Print"],
Cell[76954, 1942, 124, 1, 20, "Print"],
Cell[77081, 1945, 126, 1, 20, "Print"],
Cell[77210, 1948, 126, 1, 20, "Print"],
Cell[77339, 1951, 126, 1, 20, "Print"],
Cell[77468, 1954, 126, 1, 20, "Print"],
Cell[77597, 1957, 125, 1, 20, "Print"]
}, Open  ]],
Cell[77737, 1961, 8343, 180, 283, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86117, 2146, 70, 1, 27, "Input"],
Cell[86190, 2149, 5330, 95, 249, 2294, 44, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
